OppiaMobile Android App Change Log — OppiaMobile 0.7.1 documentation

# OppiaMobile Android App Change Log

## v51 (5.x) - not yet released

- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/391 - allow password reset using email
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/383 - quizzes getting recorded twice in tracker
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/393 - implement URl activity
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/370 - Enable rotating of the course and media download activities
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/375 - Check there is sufficient space on device storage for downloading/moving files
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/376 - Give option in preferences to move the storage location
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/334 - Fix action bar theme colours
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/203 - Allow screen rotation for tag select
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/349 - Reloading quiz/feedback after language change

## v50 (5.0.1) - released: 30 Dec 2014

- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/372 - static prefs
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/379 - setting to disable logout menu option
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/380 - setting to disable course delete
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/377 - setting to allow media download via cellular network
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/367 - collapse keyboard between quiz questions
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/378 - Apply ViewHolder pattern in ArrayAdapters
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/388 - Require phone no on registration
- https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/390 - highlighting wrong categories on tag select

## v49 (5.0.0) - released beta version: 18 Nov 2014

- Fix https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/355 - preventing media being visible to other apps
- Fix https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/371 - use custom media player
- Fix https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/352 - more reliable recording of media activity
- Fix https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/337 - move file storage to new location

## v48 (4.1.2) - released: 1 Oct 2014

- Fix https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/364 - prevent error when directory in downloads dir
- Fix https://github.com/DigitalCampus/mquiz-jar/issues/issue/5 - prevent error when response title is an int rather than string